AtomicI8

Type Alias AtomicI8 

1.34.0 · Source
pub(crate) type AtomicI8 = Atomic<i8>;
An integer type which can be safely shared between threads.

This type has the same size, alignment, and bit validity as the underlying integer type, i8.

For more about the differences between atomic types and non-atomic types as well as information about the portability of this type, please see the module-level documentation.

Note: This type is only available on platforms that support atomic loads and stores of i8.

Aliased Type

#[repr(C)]
pub(crate) struct AtomicI8 { /* private fields */ }