AtomicIsize

Type Alias AtomicIsize 

1.0.0 · Source
pub(crate) type AtomicIsize = Atomic<isize>;
An integer type which can be safely shared between threads.

This type has the same size and bit validity as the underlying integer type, isize. However, the alignment of this type is always equal to its size, even on targets where isize has a lesser alignment.

For more about the differences between atomic types and non-atomic types as well as information about the portability of this type, please see the module-level documentation.

Note: This type is only available on platforms that support atomic loads and stores of isize.

Aliased Type

#[repr(C)]
pub(crate) struct AtomicIsize { /* private fields */ }