AtomicU16

Type Alias AtomicU16 

1.34.0 · Source
pub(crate) type AtomicU16 = Atomic<u16>;
An integer type which can be safely shared between threads.

This type has the same size and bit validity as the underlying integer type, u16. However, the alignment of this type is always equal to its size, even on targets where u16 has a lesser alignment.

For more about the differences between atomic types and non-atomic types as well as information about the portability of this type, please see the module-level documentation.

Note: This type is only available on platforms that support atomic loads and stores of u16.

Aliased Type

#[repr(C)]
pub(crate) struct AtomicU16 { /* private fields */ }