AtomicUsize

Type Alias AtomicUsize 

1.0.0 · Source
pub(crate) type AtomicUsize = Atomic<usize>;
An integer type which can be safely shared between threads.

This type has the same size and bit validity as the underlying integer type, usize. However, the alignment of this type is always equal to its size, even on targets where usize has a lesser alignment.

For more about the differences between atomic types and non-atomic types as well as information about the portability of this type, please see the module-level documentation.

Note: This type is only available on platforms that support atomic loads and stores of usize.

Aliased Type

#[repr(C)]
pub(crate) struct AtomicUsize { /* private fields */ }