pub(crate) type AtomicBool = Atomic<bool>;Expand description
A boolean type which can be safely shared between threads.
This type has the same size, alignment, and bit validity as a bool.
Note: This type is only available on platforms that support atomic
loads and stores of u8.
Aliased Type
#[repr(C)]pub(crate) struct AtomicBool { /* private fields */ }Trait Implementations
Sourceimpl AtomicConsume for AtomicBool
Available on non-crossbeam_no_atomic only.
impl AtomicConsume for AtomicBool
Available on non-
crossbeam_no_atomic only.